@@ -112,7 +112,9 @@ modelfuzzy_possibilistic <-
   datadea.mR <- structure(list(input = input.mR, output = output.mR, dmunames = dmunames), class = "deadata")
   
   # Checking h
-  if (any(h > 1) || any(h < 0)){
+  if ((length(h) == 1) && (h > 1)){
+    h <- seq(from = 0, to = 1, length.out = h)
+  } else if (any(h > 1) || any(h < 0)){
     stop("Invalid h vector.")
   }
   h <- sort(unique(h))
